@@ -301,7 +301,6 @@ RESERVED_WORDS = list(sorted(set(DDL_RESERVED_WORDS + SELECT_STATEMENT_RESERVED_
 
 
 class AthenaDMLIdentifierPreparer(IdentifierPreparer):
-
     reserved_words = RESERVED_WORDS
 
 
@@ -755,7 +754,6 @@ class AthenaDDLCompiler(DDLCompiler):
 
 
 class AthenaDialect(DefaultDialect):
-
     name = "awsathena"
     preparer = AthenaDMLIdentifierPreparer
     statement_compiler = AthenaStatementCompiler
@@ -888,10 +886,18 @@ class AthenaDialect(DefaultDialect):
         return [s.name for s in schemas]
 
     def get_table_names(self, connection, schema=None, **kw):
+        # Tables created by Athena are always classified as `EXTERNAL_TABLE`,
+        # but Athena can also query tables classified as `MANAGED_TABLE`.
+        # Managed Tables are created by default when creating tables via Spark when
+        # Glue has been enabled as the Hive Metastore for Elastic Map Reduce (EMR) clusters.
+        # With Athena Federation, tables in the database that are connected to Athena via lambda
+        # function, is classified as `EXTERNAL` and fully queryable
         tables = self._get_tables(connection, schema, **kw)
-        # In Athena, only EXTERNAL_TABLE is supported.
-        # https://docs.aws.amazon.com/athena/latest/APIReference/API_TableMetadata.html
-        return [t.name for t in tables if t.table_type == "EXTERNAL_TABLE"]
+        return [
+            t.name
+            for t in tables
+            if t.table_type in ["EXTERNAL_TABLE", "MANAGED_TABLE", "EXTERNAL"]
+        ]
 
     def get_view_names(self, connection, schema=None, **kw):
         tables = self._get_tables(connection, schema, **kw)
